# frozen_string_literal: true

#
# @summary Return the script to validate if a specified sysctl value is set correct
#
# See the file "LICENSE" for the full license governing this code.
#
Puppet::Functions.create_function('linux_secured::sysctl_value') do
  dispatch :sysctl_value do
    param 'String[1]', :parameter
    param 'String[1]', :value
    return_type 'String[1]'
  end

  def sysctl_value(parameter, value)
    <<~EOD
    #!/usr/bin/env bash

    {
      krp="" pafile="" fafile=""
      kpname="#{parameter}" 
      kpvalue="#{value}"
      searchloc="/run/sysctl.d/*.conf /etc/sysctl.d/*.conf /usr/local/lib/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /lib/sysctl.d/*.conf /etc/sysctl.conf"
      krp="$(sysctl "$kpname" | awk -F= '{print $2}' | xargs)"
      pafile="$(grep -Psl -- "^\\h*$kpname\\h*=\\h*$kpvalue\\b\\h*(#.*)?$" $searchloc)"
      fafile="$(grep -s -- "^\s*$kpname" $searchloc | grep -Pv -- "\\h*=\\h*$kpvalue\\b\\h*" | awk -F: '{print $1}')"
      if [ "$krp" = "$kpvalue" ] && [ -n "$pafile" ] && [ -z "$fafile" ]; then
          echo -e "\\nPASS:\\n\\"$kpname\\" is set to \\"$kpvalue\\" in the running configuration and in \\"$pafile\\""
      else
          echo -e "\\nFAIL: "
          [ "$krp" != "$kpvalue" ] && echo -e "\\"$kpname\\" is set to \\"$krp\\" in the running configuration\\n"
          [ -n "$fafile" ] && echo -e "\\n\\"$kpname\\" is set incorrectly in \\"$fafile\\""
          [ -z "$pafile" ] && echo -e "\\n\\"$kpname = $kpvalue\\" is not set in a kernel parameter configuration file\\n"
      fi
    }

    EOD
  end
end
  