#
# linux_secured::controls::audit_backlog_limit_is_sufficient
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe backlog limit has a default setting of 64## RationaleDuring boot if audit=1, then the backlog will hold 64 records. If more than 64 records are created during boot, `auditd` records will be lost and potential malicious activity could go undetected.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::audit_backlog_limit_is_sufficient: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `audit_backlog_limit_is_sufficient` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.1.4- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.1.4
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::audit_backlog_limit_is_sufficient (
  Integer[8192] $preferred_value = linux_secured::lookup_setting('preferred_value', 8192),
) {
  linux_secured_setup { "audit_backlog_limit_is_sufficient on ${title}":
    ensure => 'present',
  }

  -> exec { 'set audit_backlog_limit sufficient':
    command => "grubby --update-kernel ALL --args 'audit_backlog_limit=${preferred_value}'",
    unless  => "find /boot -type f -name 'grubenv' -exec grep -P 'kernelopts=([^#\\n\\r]+\\h+)?(audit_backlog_limit=\\S+\\b)' {} \\; | grep 'audit_backlog_limit=${preferred_value}'",
    path    => ['/usr/sbin/', '/usr/bin'],
  }
}
