#
# linux_secured::controls::audit_log_storage_size_is_configured
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlConfigure the maximum size of the audit log file. Once the log reachesthe maximum size, it will be rotated and a new log file will be started.## RationaleIt is important that an appropriate size is determined for log files so that they do not impact the system and audit data is not lost.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::audit_log_storage_size_is_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `audit_log_storage_size_is_configured` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.2.1- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.2.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::audit_log_storage_size_is_configured (
  Integer[8] $preferred_value = linux_secured::lookup_setting('preferred_value', 8),
) {
  linux_secured_setup { "audit_log_storage_size_is_configured on ${title}":
    ensure => 'present',
  }

  -> ini_setting { ' audit log storage size is configured':
    ensure  => present,
    path    => '/etc/audit/auditd.conf',
    setting => 'max_log_file',
    value   => $preferred_value,
  }
}
