#
# linux_secured::controls::authentication_is_required_when_booting_into_rescue_mode
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlRescue mode (former single user mode) is used for recovery when thesystem detects an issue during boot or by manual selection from the bootloader.## RationaleRequiring authentication in rescue mode (former single user mode) prevents an unauthorized user from rebooting the system into rescue mode to gain root privileges without credentials.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::authentication_is_required_when_booting_into_rescue_mode: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `authentication_is_required_when_booting_into_rescue_mode` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.4.3- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.4.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::authentication_is_required_when_booting_into_rescue_mode () {
  $props = {
    owner  => 'root',
    group  => 'root',
    mode   => '0755',
  }

  linux_secured_setup { "authentication_is_required_when_booting_into_rescue_mode on ${title}":
    ensure => 'present',
  }

  -> file { '/etc/systemd/system/rescue.service.d':
    ensure => 'directory',
    *      => $props,
  }

  # lint:ignore:strict_indent
  -> file { '/etc/systemd/system/rescue.service.d/00-require-auth.conf':
    ensure  => 'file',
    content => @(CONTENT),
      [Service]
      ExecStart=-/usr/lib/systemd/systemd-sulogin-shell rescue
      | CONTENT
    *       => $props,
  }
  # lint:endignore:strict_indent
}
