#
# linux_secured::controls::automatic_mounting_of_removable_media_is_disabled
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlBy default GNOME automatically mounts removable media when insertedas a convenience to the user.## RationaleWith automounting enabled anyone with physical access could attach a USB drive or disc and have its contents available in system even if they lacked permissions to mount it themselves.## ImpactThe use of portable hard drives is very common for workstation users. If your organization allows the use of portable storage or media on workstations and physical access controls to workstations is considered adequate there is little value add in turning off automounting.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::automatic_mounting_of_removable_media_is_disabled: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `automatic_mounting_of_removable_media_is_disabled` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.8.5- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.8.5
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::automatic_mounting_of_removable_media_is_disabled () {
  linux_secured_setup { "automatic_mounting_of_removable_media_is_disabled on ${title}":
    ensure => 'present',
  }

  unless defined(Package[dconf]) {
    package { 'dconf':
      ensure => 'present',
    }
  }

  file { '/etc/dconf/db/local.d':
    ensure => 'directory',
  }

  file { '/etc/dconf/db/local.d/00-media-automount':
    ensure  => 'file',
    # lint:ignore:strict_indent
    content => @(CONTENT),
    [org/gnome/desktop/media-handling]
    automount=false
    automount-open=false
    | CONTENT
    # lint:endignore:strict_indent
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
  }
  ~> exec { 'Apply automount changes':
    command     => '/bin/dconf update',
    refreshonly => true,
    require     => Package['dconf'],
  }
}
