#
# linux_secured::controls::changes_to_system_administration_scope_sudoers_is_collected
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlMonitor scope changes for system administrators. If the system hasbeen properly configured to force system administrators to log in as themselvesfirst and then use the sudo command to execute privileged commands, it is possibleto monitor changes in scope. The file `/etc/sudoers`, or files in `/etc/sudoers.d`,will be written to when the file(s) or related attributes have changed. The auditrecords will be tagged with the identifier \"scope\".## RationaleChanges in the `/etc/sudoers` and `/etc/sudoers.d` files can indicate that an unauthorized change has been made to the scope of system administrator activity.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::changes_to_system_administration_scope_sudoers_is_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `changes_to_system_administration_scope_sudoers_is_collected` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.1- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::changes_to_system_administration_scope_sudoers_is_collected () {
  linux_secured_setup { "changes_to_system_administration_scope_sudoers_is_collected on ${title}":
    ensure => 'present',
  }

  file { '/etc/audit/rules.d/50-scope.rules':
    ensure  => 'file',
    # lint:ignore:strict_indent
    content => @(CONTENT),
    -w /etc/sudoers -p wa -k scope
    -w /etc/sudoers.d -p wa -k scope
    | CONTENT
    # lint:endignore:strict_indent
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    notify  => Exec['refresh audit deamon'],
  }

  include linux_secured::internal::refresh_audit_daemon
}
