#
# linux_secured::controls::chrony_is_configured
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlchrony is a daemon which implements the Network Time Protocol (NTP)and is designed to synchronize system clocks across a variety of systems and usea source that is highly accurate. More information on chrony can be found at http://chrony.tuxfamily.org/.chrony can be configured to be a client and/or a server.## RationaleIf chrony is in use on the system proper configuration is vital to ensuring time synchronization is working properly.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::chrony_is_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `chrony_is_configured` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 2.1.2- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 2.1.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::chrony_is_configured (
  Optional[String[1]] $server  = linux_secured::lookup_setting('server', undef),
  Optional[String[1]] $pool    = linux_secured::lookup_setting('pool', undef),
  String              $options = linux_secured::lookup_setting('options', ''),
) {
  linux_secured_setup { "chrony_is_configured on ${title}":
    ensure => 'present',
  }
  -> ini_setting { 'Configure Chromy daemon':
    ensure            => present,
    path              => '/etc/sysconfig/chronyd',
    key_val_separator => '=',
    setting           => 'OPTIONS',
    value             => '"-u chrony"',
  }
  if $server == undef and $pool == undef {
    easy_type::delegate_to_validator()
  } else {
    if $server != undef {
      $key   = 'server'
      $value = $server
    } elsif $pool != undef {
      $key = 'pool'
      $value = $pool
    }

    ini_setting { 'Chromy pool or server config':
      ensure            => present,
      path              => '/etc/chrony.conf',
      key_val_separator => ' ',
      setting           => $key,
      value             => "${value} ${options}",
    }
  }
}
