#
# linux_secured::controls::default_user_shell_timeout_is_900_seconds_or_less
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the control`TMOUT` is an environmental setting that determines the timeout of a shell in seconds.- `TMOUT=n` - Sets the shell timeout to n seconds. A setting of `TMOUT=0` disables timeout.- readonly `TMOUT`- Sets the `TMOUT` environmental variable as readonly, preventing unwanted modification during run-time.- export `TMOUT` - exports the `TMOUT` variable System Wide Shell Configuration Files:- `/etc/profile` - used to set system wide environmental variables on users shells. The variables are sometimes the same ones that are in the .bash_profile, however this file is used to set an initial PATH or PS1 for all shell users of the system. is only executed for interactive login shells, or shells executed with the --login parameter.- /`etc/profile.d` - `/etc/profile` will execute the scripts within /`etc/profile.d`/*.sh. It is recommended to place your configuration in a shell script within /`etc/profile.d` to set your own system wide environmental variables.- `/etc/bashrc` - System wide version of `.bashrc`. In Fedora derived distributions, etc/bashrc also invokes /`etc/profile.d/*.sh` if non-login shell, but redirects output to `/dev/null` if non-interactive. Is only executed for interactive shells or if `BASH_ENV` is set to `/etc/bashrc`.## RationaleSetting a timeout value reduces the window of opportunity for unauthorized user access to another user's shell session that has been left unattended. It also ends the inactive session and releases the resources associated with that session.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::default_user_shell_timeout_is_900_seconds_or_less: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `default_user_shell_timeout_is_900_seconds_or_less` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.6.3- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.6.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::default_user_shell_timeout_is_900_seconds_or_less () {
  linux_secured_setup { "default_user_shell_timeout_is_900_seconds_or_less on ${title}":
    ensure => 'present',
  }

  # lint:ignore:strict_indent
  file { '/etc/profile.d/user_shell_timeout.sh':
    ensure  => 'file',
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => @(CONTENT),
    TMOUT=900
    readonly TMOUT
    export TMOUT
    | CONTENT
  }
  # lint:endignore:strict_indent
}
