#
# linux_secured::controls::events_that_modify_date_and_time_information_are_collected
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlCapture events where the system date and/or time has been modified. The parameters in this section are set to determine if the;    - `adjtimex` - tune kernel clock- `settimeofday` - set time using `timeval` and `timezone` structures- `stime` - using seconds since 1/1/1970- `clock_settime` - allows for the setting of several internal clocks and timerssystem calls have been executed. Further, ensure to write an audit record to the configured audit log file upon exit, tagging the records with a unique identifier such as "time-change".## RationaleUnexpected changes in system date and/or time could be a sign of malicious activity on the system.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::events_that_modify_date_and_time_information_are_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `events_that_modify_date_and_time_information_are_collected` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.4- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.4
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::events_that_modify_date_and_time_information_are_collected () {
  linux_secured_setup { "events_that_modify_date_and_time_information_are_collected on ${title}":
    ensure => 'present',
  }

  -> file { '/etc/audit/rules.d/50-time-change.rules':
    ensure  => 'file',
    # lint:ignore:strict_indent
    content => @(CONTENT),
    -a always,exit -F arch=b64 -S adjtimex,settimeofday,clock_settime -k time-change
    -a always,exit -F arch=b32 -S adjtimex,settimeofday,clock_settime -k time-change
    -w /etc/localtime -p wa -k time-change
    | CONTENT
    # lint:endignore:strict_indent
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    notify  => Exec['refresh audit deamon'],
  }

  include linux_secured::internal::refresh_audit_daemon
}
