#
# linux_secured::controls::events_that_modify_the_sudo_log_file_are_collected
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlMonitor the sudo log file. If the system has been properly configuredto disable the use of the su command and force all administrators to have to login first and then use sudo to execute privileged commands, then all administratorcommands will be logged to `/var/log/sudo.log` . Any time a command is executed,an audit event will be triggered as the `/var/log/sudo.log` file will be openedfor write and the executed administration command will be written to the log.## RationaleChanges in `/var/log/sudo.log` indicate that an administrator has executed a command or the log file itself has been tampered with. Administrators will want to correlate the events written to the audit trail with the records written to `/var/log/sudo.log` to verify if unauthorized commands have been executed.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::events_that_modify_the_sudo_log_file_are_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `events_that_modify_the_sudo_log_file_are_collected` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.3- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::events_that_modify_the_sudo_log_file_are_collected (
  Stdlib::Absolutepath $sudo_log_file = linux_secured::lookup_setting('sudo_log_file', '/var/log/sudo.log'),
) {
  linux_secured_setup { "events_that_modify_the_sudo_log_file_are_collected on ${title}":
    ensure => 'present',
  }

  -> file { '/etc/audit/rules.d/50-sudo.rules':
    ensure  => 'file',
    content => "-w ${sudo_log_file} -p wa -k sudo_log_file\n",
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    notify  => Exec['refresh audit deamon'],
  }

  include linux_secured::internal::refresh_audit_daemon
}
