#
# linux_secured::controls::file_deletion_events_by_users_are_collected
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlMonitor the use of system calls associated with the deletion or renaming of files and file attributes. This configuration statement sets up monitoring for:- `unlink` - remove a file- `unlinkat` - remove a file attribute- `rename` - rename a file- `renameat` `rename` a file attribute system calls and tags them with the identifier"delete".## RationaleMonitoring these calls from non-privileged users could provide a system administrator with evidence that inappropriate removal of files and file attributes associated with protected files is occurring. While this audit option will look at all events, system administrators will want to look for specific privileged files that are being deleted or altered.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::file_deletion_events_by_users_are_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `file_deletion_events_by_users_are_collected` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.13- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.13
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::file_deletion_events_by_users_are_collected () {
  linux_secured_setup { "file_deletion_events_by_users_are_collected on ${title}":
    ensure => 'present',
  }

  -> file { '/etc/audit/rules.d/50-delete.rules':
    ensure  => 'file',
    # lint:ignore:strict_indent
    content => @("CONTENT"),
    -a always,exit -F arch=b64 -S rename,unlink,unlinkat,renameat -F auid>=${facts['uid_min'] } -F auid!=unset -F key=delete
    -a always,exit -F arch=b32 -S rename,unlink,unlinkat,renameat -F auid>=${facts['uid_min'] } -F auid!=unset -F key=delete
    | CONTENT
    # lint:endignore:strict_indent
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    notify  => Exec['refresh audit deamon'],
  }
  include linux_secured::internal::refresh_audit_daemon
}
