#
# linux_secured::controls::filesystem_integrity_is_regularly_checked
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlPeriodic checking of the filesystem integrity is needed to detectchanges to the filesystem.## RationalePeriodic file checking allows the system administrator to determine on a regular basis if critical files have been changed in an unauthorized fashion.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::filesystem_integrity_is_regularly_checked: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `filesystem_integrity_is_regularly_checked` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.3.2- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.3.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::filesystem_integrity_is_regularly_checked (
  String[1] $time = linux_secured::lookup_setting('time', '05:00:00'),
) {
  linux_secured_setup { "filesystem_integrity_is_regularly_checked on ${title}":
    ensure => 'present',
  }

  $props = {
    'owner'   => 'root',
    'group'   => 'root',
    'mode'    => '0644',
    'require' => Linux_secured_setup["filesystem_integrity_is_regularly_checked on ${title}"],
  }

  # lint:ignore:strict_indent
  file { '/etc/systemd/system/aidecheck.service':
    ensure  => 'file',
    content => @(CONTENT),
               [Unit]
               Description=Aide Check

               [Service]
               Type=simple
               ExecStart=/usr/sbin/aide --check

               [Install]
               WantedBy=multi-user.target
               | CONTENT
    *       => $props,
  }

  file { '/etc/systemd/system/aidecheck.timer':
    ensure  => 'file',
    content => @("CONTENT"),
               [Unit]
               Description=Aide check every day at ${time}
               
               [Timer]
               OnCalendar=*-*-* ${time}
               Unit=aidecheck.service
               
               [Install]
               WantedBy=multi-user.target
               | CONTENT
    *       => $props,
  }
  # lint:endignore:strict_indent

  exec { 'reload after AIDE check services update':
    command     => '/usr/bin/systemctl daemon-reload',
    refreshonly => true,
    subscribe   => [
      File['/etc/systemd/system/aidecheck.service'],
      File['/etc/systemd/system/aidecheck.timer'],
    ],
  }

  -> service { 'aidecheck.service':
    enable => true,
  }

  -> exec { 'Start aidecheck.timer':
    command => 'systemctl --now enable aidecheck.timer',
    path    => ['/usr/sbin/', '/usr/bin'],
    unless  => "systemctl status aidecheck.timer | grep 'Active: active'",
  }
}
