#
# linux_secured::controls::firewalld_default_zone_is_set
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlA firewall zone defines the trust level for a connection, interface or source address binding. This is a one to many relation, which means that a connection, interface or source can only be part of one zone, but a zone can be used for many network connections, interfaces and sources.- The default zone is the zone that is used for everything that is not explicitly bound/assigned to another zone.Connections handled by NetworkManager are listed as NetworkManager requests to add the zone binding for the interface used by the connection. Also interfaces under control of the network service are listed also because the service requests it.**Note**:- A firewalld zone configuration file contains the information for a zone.    o These are the zone description, services, ports, protocols, icmp-blocks,masquerade, forward-ports and rich language rules in an XML file format.o The file name has to be zone_name.xml where length of zone_name is currentlylimited to 17 chars.- NetworkManager binds interfaces to zones automatically## RationaleBecause the default zone is the zone that is used for everything that is not explicitly bound/assigned to another zone, it is important for the default zone to set## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::firewalld_default_zone_is_set: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `firewalld_default_zone_is_set` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.4.1.5- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.4.1.5
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::firewalld_default_zone_is_set (
  Optional[String[1]] $default_zone = linux_secured::lookup_setting('default_zone', undef),
) {
  linux_secured_setup { "firewalld_default_zone_is_set on ${title}":
    ensure => 'present',
  }

  if $default_zone == undef {
    easy_type::delegate_to_validator()
  } else {
    exec { 'set firewalld default zone':
      command => "firewall-cmd --set-default-zone=${default_zone}",
      unless  => "firewall-cmd --get-default-zone | grep ${default_zone}",
      path    => ['/usr/sbin/', '/usr/bin'],
    }
  }
}
