#
# linux_secured::controls::gpgcheck_is_globally_activated
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe gpgcheck option, found in the main section of the `/etc/dnf/dnf.conf`and individual `/etc/yum.repos.d/*` files, determines if an RPM package's signatureis checked prior to its installation.## RationaleIt is important to ensure that an RPM's package signature is always checked prior to installation to ensure that the software is obtained from a trusted source.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::gpgcheck_is_globally_activated: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `gpgcheck_is_globally_activated` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.2.2- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.2.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::gpgcheck_is_globally_activated () {
  linux_secured_setup { "gpgcheck_is_globally_activated on ${title}":
    ensure => 'present',
  }

  $facts['repos_with_gpg_disabled'].each |$repo| {
    yumrepo { $repo:
      gpgcheck => '1',
      require  => Linux_secured_setup["gpgcheck_is_globally_activated on ${title}"],
    }
  }
}
