#
# linux_secured::controls::iptables_loopback_traffic_is_configured
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlConfigure the loopback interface to accept traffic. Configure allother interfaces to deny traffic to the loopback network (127.0.0.0/8).## RationaleLoopback traffic is generated between processes on machine and is typically critical to operation of the system. The loopback interface is the only place that loopback network (127.0.0.0/8) traffic should be seen, all other interfaces should ignore traffic on this network as an anti-spoofing measure.**Note**: Changing firewall settings while connected over network can result in being locked out of the system.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::iptables_loopback_traffic_is_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `iptables_loopback_traffic_is_configured` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.4.3.2.1- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.4.3.2.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::iptables_loopback_traffic_is_configured () {
  linux_secured_setup { "iptables_loopback_traffic_is_configured on ${title}":
    ensure => 'present',
  }

  -> exec { "Configure loopback interface to accept incomming traffic on ${title}":
    command => 'iptables -A INPUT -i lo -j ACCEPT',
    unless  => "iptables -L INPUT -v -n | grep 'ACCEPT     all  --  lo     \\*       0.0.0.0\\/0            0.0.0.0\\/0'",
    path    => ['/usr/sbin/', '/usr/bin'],
  }

  -> exec { "Configure loopback interface to accept outgoing traffic on ${title}":
    command => 'iptables -A OUTPUT -o lo -j ACCEPT',
    unless  => "iptables -L OUTPUT -v -n | grep 'ACCEPT     all  --  \\*      lo      0.0.0.0\\/0            0.0.0.0\\/0'",
    path    => ['/usr/sbin/', '/usr/bin'],
  }

  -> exec { "Configure all other interface to drop traffic to the loopback network on ${title}":
    command => 'iptables -A INPUT -s 127.0.0.0/8 -j DROP',
    unless  => "iptables -L INPUT -v -n | grep 'DROP       all  --  \\*      \\*       127.0.0.0\\/8          0.0.0.0\\/0'",
    path    => ['/usr/sbin/', '/usr/bin'],
  }
}
