#
# linux_secured::controls::iptables_packages_are_installed
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controliptables is a utility program that allows a system administrator toconfigure the tables provided by the Linux kernel firewall, implemented as differentNetfilter modules, and the chains and rules it stores. Different kernel modulesand programs are used for different protocols; iptables applies to IPv4, ip6tablesto IPv6, arptables to ARP, and ebtables to Ethernet frames.## RationaleA method of configuring and maintaining firewall rules is necessary to configure a Host Based Firewall.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::iptables_packages_are_installed: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `iptables_packages_are_installed` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.4.3.1.1- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.4.3.1.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::iptables_packages_are_installed () {
  linux_secured_setup { "iptables_packages_are_installed on ${title}":
    ensure => 'present',
  }

  $random = easy_type::random_id(8)
  # lint:ignore:manifest_whitespace_opening_bracket_before
  ['iptables', 'iptables-services'].each |$package| {
    resource_value { "Package[${package}]ensure/${random}":
      value          => 'present',
      allow_create   => true,
      allow_redefine => true,
    }
  }
  # lint:endignore:manifest_whitespace_opening_bracket_before
}
