#
# linux_secured::controls::kernel_module_loading_unloading_and_modification_is_collected
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlMonitor the loading and unloading of kernel modules. All the loading / listing / dependency checking of modules is done by kmod via symbolic links.The following system calls control loading and unloading of modules:- `init_module` - load a module- `finit_module` - load a module (used when the overhead of using cryptographicallysigned modules to determine the authenticity of a module can be avoided)- `delete_module` - delete a module- `create_module` - create a loadable module entry- `query_module` - query the kernel for various bits pertaining to modulesAny execution of the loading and unloading module programs and system calls will trigger an audit record with an identifier of modules.## RationaleMonitoring the use of all the various ways to manipulate kernel modules could provide system administrators with evidence that an unauthorized change was made to a kernel module, possibly compromising the security of the system.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::kernel_module_loading_unloading_and_modification_is_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `kernel_module_loading_unloading_and_modification_is_collected` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.19- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.19
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::kernel_module_loading_unloading_and_modification_is_collected {
  linux_secured_setup { "kernel_module_loading_unloading_and_modification_is_collected on ${title}":
    ensure => 'present',
  }

  -> file { '/etc/audit/rules.d/50-kernel_modules.rules':
    ensure  => 'file',
    # lint:ignore:strict_indent
    content => @("CONTENT"),
    -a always,exit -F arch=b64 -S init_module,finit_module,delete_module,create_module,query_module -F auid>=${facts['uid_min'] } -F auid!=unset -k kernel_modules
    -a always,exit -F path=/usr/bin/kmod -F perm=x -F auid>=${facts['uid_min'] } -F auid!=unset -k kernel_modules
    | CONTENT
    # lint:endignore:strict_indent
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    notify  => Exec['refresh audit deamon'],
  }
  include linux_secured::internal::refresh_audit_daemon
}
