#
# linux_secured::controls::last_logged_in_user_display_is_disabled
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlGDM is the GNOME Display Manager which handles graphical login forGNOME based systems.## RationaleDisplaying the last logged in user eliminates half of the Userid/Password equation that an unauthorized person would need to log on.Warning messages inform users who are attempting to login to the system of their legal status regarding the system and must include the name of the organization that owns the system and any monitoring policies that are in place.Notes:- If a graphical login is not required, it should be removed to reduce the attack surface of the system.- If a different GUI login service is in use and required on the system, consult your documentation to disable displaying the last logged on user## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::last_logged_in_user_display_is_disabled: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `last_logged_in_user_display_is_disabled` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.8.3- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.8.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::last_logged_in_user_display_is_disabled () {
  linux_secured_setup { "last_logged_in_user_display_is_disabled on ${title}":
    ensure => 'present',
  }

  require linux_secured::internal::gdm_config

  file { '/etc/dconf/db/gdm.d/00-login-screen':
    ensure  => 'file',
    # lint:ignore:strict_indent
    content => @("CONTENT"),
    [org/gnome/login-screen]
    disable-user-list=true
    | CONTENT
    # lint:endignore:strict_indent
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    require => Linux_secured_setup["last_logged_in_user_display_is_disabled on ${title}"],
  }
}
