#
# linux_secured::controls::ldap_client_is_not_installed
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe Lightweight Directory Access Protocol (LDAP) was introduced asa replacement for NIS/YP. It is a service that provides a method for looking upinformation from a central database.## RationaleIf the system will not need to act as an LDAP client, it is recommended that the software be removed to reduce the potential attack surface.## ImpactRemoving the LDAP client will prevent or inhibit using LDAP for authentication in your environment.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::ldap_client_is_not_installed: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `ldap_client_is_not_installed` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 2.3.5- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 2.3.5
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::ldap_client_is_not_installed () {
  linux_secured_setup { "ldap_client_is_not_installed on ${title}":
    ensure => 'present',
  }

  -> package { 'openldap-clients':
    ensure => 'purged',
  }
}
