#
# linux_secured::controls::minimum_days_between_password_changes_is_7_or_more
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `PASS_MIN_DAYS` parameter in /etc/login.defs allows an administratorto prevent users from changing their password until a minimum number of days have## RationaleBy restricting the frequency of password changes, an administrator can prevent users from repeatedly changing their password in an attempt to circumvent password reuse controls.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::minimum_days_between_password_changes_is_7_or_more: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `minimum_days_between_password_changes_is_7_or_more` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.6.1.2- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.6.1.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::minimum_days_between_password_changes_is_7_or_more (
  Integer[7] $min_expiration_time = linux_secured::lookup_setting('min_expiration_time', 7)
) {
  linux_secured_setup { "minimum_days_between_password_changes_is_7_or_more on ${title}":
    ensure => 'present',
  }

  -> file_line { 'set minimum password expiration policy':
    ensure => present,
    path   => '/etc/login.defs',
    line   => "PASS_MIN_DAYS  ${min_expiration_time}",
    match  => '^#?PASS_MIN_DAYS',
  }

  $facts['users_with_short_expiration'].each |$user| {
    resource_value { "User[${user}]password_min_age":
      allow_create => true,
      value        => $min_expiration_time,
    }
  }
}
