#
# linux_secured::controls::password_creation_requirements_are_configured
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `pam_pwquality.so` module checks the strength of passwords. It performs checks such as making sure a password is not a dictionary word, it is a certain length, contains a mix of characters (e.g. alphabet, numeric, other) and more. The following are definitions of the p`am_pwquality.so` options.- `try_first_pass` - retrieve the password from a previous stacked PAM module. If not available, then prompt the user for a password.- `retry=3` - Allow 3 tries before sending back a failure.- `minlen=14` - password must be 14 characters or more** Either of the following can be used to enforce complex passwords:**- `minclass=4` - provide at least four classes of characters for the new passwordOR- `dcredit=-1` - provide at least one digit- `ucredit=-1` - provide at least one uppercase character- `ocredit=-1` - provide at least one special character- `lcredit=-1` - provide at least one lowercase characterThe settings shown above are one possible policy. Alter these values to conform to your own organization's password policies## RationaleStrong passwords protect systems from being hacked through brute force methods.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::password_creation_requirements_are_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `password_creation_requirements_are_configured` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.5.1- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.5.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::password_creation_requirements_are_configured (
  Integer[14] $min_password_length = linux_secured::lookup_setting('min_password_length', 14),
) {
  linux_secured_setup { "password_creation_requirements_are_configured on ${title}":
    ensure => 'present',
  }
  # TODO: add other settings
  -> file_line { 'configure password length requirements':
    ensure => 'present',
    path   => '/etc/security/pwquality.conf',
    line   => "minlen=${min_password_length}",
    match  => '^#?minlen',
  }

  -> file_line { 'configure password complexity requirements':
    ensure => 'present',
    path   => '/etc/security/pwquality.conf',
    line   => 'minclass=4',
    match  => '^#?minclass',
  }
  alert('Specified CIS control is not (yet) fully automatically enforced.')
}
