#
# linux_secured::controls::password_expiration_is_365_days_or_less
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `PASS_MAX_DAYS` parameter in `/etc/login.defs` allows an administrator## RationaleThe window of opportunity for an attacker to leverage compromised credentials or successfully compromise credentials via an online brute force attack is limited by the age of the password. Therefore, reducing the maximum age of a password also reduces an attacker's window of opportunity.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::password_expiration_is_365_days_or_less: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `password_expiration_is_365_days_or_less` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.6.1.1- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.6.1.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::password_expiration_is_365_days_or_less (
  Integer[0,365] $max_expiration_time = linux_secured::lookup_setting('max_expiration_time', 365)
) {
  linux_secured_setup { "password_expiration_is_365_days_or_less on ${title}":
    ensure => 'present',
  }

  file_line { 'set maximum password expiration policy':
    ensure => present,
    path   => '/etc/login.defs',
    line   => "PASS_MAX_DAYS ${max_expiration_time}",
    match  => '^#?PASS_MAX_DAYS',
  }

  $facts['users_with_long_expiration'].each |$user| {
    resource_value { "User[${user}]password_max_age":
      allow_create => true,
      value        => $max_expiration_time,
    }
  }
}
