#
# linux_secured::controls::password_expiration_warning_days_is_7_or_more
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `PASS_WARN_AGE` parameter in /etc/login.defs allows an administratorto notify users that their password will expire in a defined number of days. Itis recommended that the `PASS_WARN_AGE` parameter be set to 7 or more days.## RationaleProviding an advance warning that a password will be expiring gives users time to think of a secure password. Users caught unaware may choose a simple password or write it down where it may be discovered.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::password_expiration_warning_days_is_7_or_more: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `password_expiration_warning_days_is_7_or_more` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.6.1.3- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.6.1.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::password_expiration_warning_days_is_7_or_more (
  Integer[7] $password_warning_days = linux_secured::lookup_setting('password_warning_days', 7)
) {
  linux_secured_setup { "password_expiration_warning_days_is_7_or_more on ${title}":
    ensure => 'present',
  }

  file_line { 'set minimum password warning policy':
    ensure => present,
    path   => '/etc/login.defs',
    line   => "PASS_WARN_AGE ${password_warning_days}",
    match  => '^PASS_WARN_AGE',
  }

  $facts['users_with_short_expiration'].each |$user| {
    resource_value { "User[${user}]password_warn_days":
      allow_create => true,
      value        => $password_warning_days,
    }
  }
}
