#
# linux_secured::controls::password_hashing_algorithm_is_sha_512
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlA cryptographic hash function converts an arbitrary-length input intoa fixed length output. Password hashing performs a one-way transformation of apassword, turning the password into another string, called the hashed password.## RationaleThe SHA-512 algorithm provides stronger hashing than other hashing algorithms used for password hashing with Linux, providing additional protection to the system by increasing the level of effort for an attacker to successfully determine passwords.**Note**: These changes only apply to accounts configured on the local system.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::password_hashing_algorithm_is_sha_512: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `password_hashing_algorithm_is_sha_512` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.5.4- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.5.4
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::password_hashing_algorithm_is_sha_512 () {
  linux_secured_setup { "password_hashing_algorithm_is_sha_512 on ${title}":
    ensure => 'present',
  }

  -> ini_setting { 'hashing algorithm is sha512 in libuser.conf':
    ensure  => present,
    path    => '/etc/libuser.conf',
    setting => 'crypt_style',
    value   => 'sha512',
  }

  -> ini_setting { 'hashing algorithm is sha512 in login.defs':
    ensure            => present,
    path              => '/etc/login.defs',
    key_val_separator => ' ',
    setting           => 'ENCRYPT_METHOD',
    value             => 'SHA512',
  }
  # TODO: Manage PAM
}
