#
# linux_secured::controls::permissions_on_all_logfiles_are_configured
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlLog files contain information from many services on the the localsystem, or in the event of a centralized log server, others systems logs as well.In general log files are found in `/var/log/`, although application can be configuredto store logs elsewhere. Should your application store logs in another, ensureto run the same test on that location.## RationaleIt is important that log files have the correct permissions to ensure that sensitive data is protected and that only the appropriate users / groups have access to them.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::permissions_on_all_logfiles_are_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `permissions_on_all_logfiles_are_configured` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.2.3- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.2.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::permissions_on_all_logfiles_are_configured () {
  linux_secured_setup { "permissions_on_all_logfiles_are_configured on ${title}":
    ensure => 'present',
  }

  # lint:ignore:recurse_file
  -> file { '/var/log/':
    mode    => '0640',
    recurse => true,
  }
  # lint:endignore:recurse_file
}
