#
# linux_secured::controls::permissions_on_etc_cron_d_are_configured
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `/etc/cron.d` directory contains system `cron` jobs that needto run in a similar manner to the hourly, daily weekly and monthly jobs from /`etc/crontab`, but require more granular control as to when they run. The files in this directorycannot be manipulated by the crontab command, but are instead edited by systemadministrators using a text editor. The commands below restrict read/write andsearch access to user and group root, preventing regular users from accessingthis directory.## RationaleGranting write access to this directory for non-privileged users could provide them the means for gaining unauthorized elevated privileges. Granting read access to this directory could give an unprivileged user insight in how to gain elevated privileges or circumvent auditing controls.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::permissions_on_etc_cron_d_are_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `permissions_on_etc_cron_d_are_configured` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.1.7- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.1.7
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::permissions_on_etc_cron_d_are_configured () {
  linux_secured_setup { "permissions_on_etc_cron_d_are_configured on ${title}":
    ensure => 'present',
  }

  -> file { '/etc/cron.d':
    owner => 'root',
    group => 'root',
    mode  => '0700',
  }
}
