#
# linux_secured::controls::reverse_path_filtering_is_enabled
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlSetting `net.ipv4.conf.all.rp_filter` and `net.ipv4.conf.default.rp`_filterto `1` forces the Linux kernel to utilize reverse path filtering on a receivedpacket to determine if the packet was valid. Essentially, with reverse path filtering,if the return packet does not go out the same interface that the correspondingsource packet came from, the packet is dropped (and logged if log_martians isset).## RationaleSetting these flags is a good way to deter attackers from sending your system bogus packets that cannot be responded to. One instance where this feature breaks down is if asymmetrical routing is employed. This would occur when using dynamic routing protocols (bgp, ospf, etc) on your system. If you are using asymmetrical routing on your system, you will not be able to enable this feature without breaking the routing.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::reverse_path_filtering_is_enabled: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `reverse_path_filtering_is_enabled` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.3.7- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.3.7
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::reverse_path_filtering_is_enabled () {
  $parameters = [
    'net.ipv4.conf.all.rp_filter',
    'net.ipv4.conf.default.rp_filter',
  ]

  linux_secured_setup { "reverse_path_filtering_is_enabled on ${title}":
    ensure => 'present',
  }

  -> sysctl { $parameters:
    ensure => present,
    value  => '1',
  }
}
