#
# linux_secured::controls::rsync_is_not_installed_or_the_rsyncd_service_is_masked
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe rsyncd service can be used to synchronize files between systemsover network links. ## RationaleUnless required, the rsync package should be removed to reduce the attack surface area of the system.The rsyncd service presents a security risk as it uses unencrypted protocols for communication. **Note**: If a required dependency exists for the rsync package, but the rsyncd service is not required, the service should be masked.## ImpactThere are packages that are dependent on the rsync package. If the rsync package is removed, these packages will be removed as well.Before removing the rsync package, review any dependent packages to determine if they are required on the system. If a dependent package is required, mask the rsyncd service and leave the rsync package installed.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::rsync_is_not_installed_or_the_rsyncd_service_is_masked: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `rsync_is_not_installed_or_the_rsyncd_service_is_masked` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 2.2.20- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 2.2.20
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::rsync_is_not_installed_or_the_rsyncd_service_is_masked () {
  linux_secured_setup { "rsync_is_not_installed_or_the_rsyncd_service_is_masked on ${title}":
    ensure => 'present',
  }

  -> service { 'rsync':
    enable => 'mask',
  }
}
