#
# linux_secured::controls::rsyslog_default_file_permissions_are_configured
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlRSyslog will create logfiles that do not already exist on the system.This setting controls what permissions will be applied to these newly createdfiles.## RationaleIt is important to ensure that log files have the correct permissions to ensure that sensitive data is archived and protected.## ImpactThe systems global `umask` could override, but only making the file permissions stricter, what is configured in RSyslog with the `FileCreateMode` directive. RSyslog also has it's own $umask directive that can alter the intended file creation mode. In addition, consideration should be given to how `FileCreateMode` is used.Thus it is critical to ensure that the intended file creation mode is not overridden with less restrictive settings in `/etc/rsyslog.conf`, `/etc/rsyslog.d/*conf` files and that `FileCreateMode` is set before any file is created.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::rsyslog_default_file_permissions_are_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `rsyslog_default_file_permissions_are_configured` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.2.1.4- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.2.1.4
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::rsyslog_default_file_permissions_are_configured () {
  linux_secured_setup { "rsyslog_default_file_permissions_are_configured on ${title}":
    ensure => 'present',
  }

  -> ini_setting { 'Configure rsyslog default file permissions':
    ensure            => present,
    path              => '/etc/rsyslog.conf',
    key_val_separator => ' ',
    setting           => '$FileCreateMode',
    value             => '0640',
  }
}
