#
# linux_secured::controls::rsyslog_is_not_configured_to_receive_logs_from_a_remote_client
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlRSyslog supports the ability to receive messages from remote hosts,thus acting as a log server. Clients should not receive data from other hosts.## RationaleIf a client is configured to also receive data, thus turning it into a server, the client system is acting outside it's operational boundary.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::rsyslog_is_not_configured_to_receive_logs_from_a_remote_client: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `rsyslog_is_not_configured_to_receive_logs_from_a_remote_client` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.2.1.7
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::rsyslog_is_not_configured_to_receive_logs_from_a_remote_client () {
  linux_secured_setup { "rsyslog_is_not_configured_to_receive_logs_from_a_remote_client on ${title}":
    ensure => 'present',
  }

  -> file_line { 'Remove module imtcp':
    ensure            => 'absent',
    path              => '/etc/rsyslog.conf',
    match             => '^module\(load="imtcp"\)',
    match_for_absence => true,
  }

  -> file_line { 'remove input imtcp':
    ensure            => 'absent',
    path              => '/etc/rsyslog.conf',
    match             => '^input\(type="imtcp" port="514"\)',
    match_for_absence => true,
  }
}
