#
# linux_secured::controls::selinux_mode_is_enforcing
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlSELinux can run in one of three modes: disabled, permissive, or enforcing:- Enforcing - Is the default, and recommended, mode of operation; in enforcing mode SELinux operates normally, enforcing the loaded security policy on the entire system.- Permissive - The system acts as if SELinux is enforcing the loaded security policy, including labeling objects and emitting access denial entries in the logs, but it does not actually deny any operations. While not recommended for production systems, permissive mode can be helpful for SELinux policy development.- Disabled - Is strongly discouraged; not only does the system avoid enforcing the SELinux policy, it also avoids labeling any persistent objects such as files, making it difficult to enable SELinux in the future**Note**: you can set individual domains to permissive mode while the system runs in enforcing mode. For example, to make the httpd_t domain permissive:```# semanage permissive -a httpd_t```## RationaleRunning SELinux in disabled mode the system not only avoids enforcing the SELinux policy, it also avoids labeling any persistent objects such as files, making it difficult to enable SELinux in the future.Running SELinux in Permissive mode, though helpful for developing SELinux policy, only logs access denial entries, but does not deny any operations.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::selinux_mode_is_enforcing: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `selinux_mode_is_enforcing` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.6.1.5- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.6.1.5
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::selinux_mode_is_enforcing () {
  linux_secured_setup { "selinux_mode_is_enforcing on ${title}":
    ensure => 'present',
  }

  exec { "Set SELinux enforcing mode on ${title}":
    command => '/sbin/setenforce 1',
    unless  => '/sbin/getenforce | /bin/grep Enforcing',
  }

  -> ini_setting { 'Ensure SELinux policy is enforced':
    ensure            => present,
    path              => '/etc/selinux/config',
    key_val_separator => '=',
    setting           => 'SELINUX',
    value             => 'enforcing',
  }
}
