#
# linux_secured::controls::session_initiation_information_is_collected
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlMonitor session initiation events. The parameters in this section track changes to the files associated with session events.- `/var/run/utmp` - tracks all currently logged in users.- `/var/log/wtmp` - file tracks logins, logouts, shutdown, and reboot events.- `/var/log/btmp` - keeps track of failed login attempts and can be read by entering thecommand `/usr/bin/last -f /var/log/btmp`.All audit records will be tagged with the identifier "session."## RationaleMonitoring these files for changes could alert a system administrator to logins occurring at unusual hours, which could indicate intruder activity (i.e. a user logging in at a time when they do not normally log in).## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::session_initiation_information_is_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `session_initiation_information_is_collected` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.11- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.11
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::session_initiation_information_is_collected () {
  linux_secured_setup { "session_initiation_information_is_collected on ${title}":
    ensure => 'present',
  }

  -> file { '/etc/audit/rules.d/50-session.rules':
    ensure  => 'file',
    # lint:ignore:strict_indent
    content => @("CONTENT"),
    -w /var/run/utmp -p wa -k session
    -w /var/log/wtmp -p wa -k session
    -w /var/log/btmp -p wa -k session
    | CONTENT
    # lint:endignore:strict_indent
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    notify  => Exec['refresh audit deamon'],
  }
  include linux_secured::internal::refresh_audit_daemon
}
