#
# linux_secured::controls::source_routed_packets_are_not_accepted
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlIn networking, source routing allows a sender to partially or fullyspecify the route packets take through a network. In contrast, non-source routedInternet routable), and so source routed packets would need to be used.## RationaleSetting `net.ipv4.conf.all.accept_source_route`, `net.ipv4.conf.default.accept_source_route`, `net.ipv6.conf.all.accept_source_route` and `net.ipv6.conf.default.accept_source_route` to `0` disables the system from accepting source routed packets. Assume this system was capable of routing packets to Internet routable addresses on one interface and private addresses on another interface. Assume that the private addresses were not routable to the Internet routable addresses and vice versa. Under normal routing circumstances, an attacker from the Internet routable addresses could not use the system as a way to reach the private address systems. If, however, source routed packets were allowed, they could be used to gain access to the private address systems as the route could be specified, rather than rely on routing protocols that did not allow this routing.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::source_routed_packets_are_not_accepted: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `source_routed_packets_are_not_accepted` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.3.1- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.3.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::source_routed_packets_are_not_accepted () {
  $parameters = if $facts['ip6_enabled'] == true {
    [
      'net.ipv4.conf.all.accept_source_route',
      'net.ipv4.conf.default.accept_source_route',
      'net.ipv6.conf.all.accept_source_route',
      'net.ipv6.conf.default.accept_source_route',
    ]
  } else {
    [
      'net.ipv4.conf.all.accept_source_route',
      'net.ipv4.conf.default.accept_source_route',
    ]
  }

  linux_secured_setup { "source_routed_packets_are_not_accepted on ${title}":
    ensure => 'present',
  }

  -> sysctl { $parameters:
    ensure  => present,
    value   => '0',
    require => Linux_secured_setup["source_routed_packets_are_not_accepted on ${title}"],
  }
}
