#
# linux_secured::controls::ssh_idle_timeout_interval_is_configured
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe two options `ClientAliveInterval` and `ClientAliveCountMax` controlthe timeout of ssh sessions.- `ClientAliveInterval` sets a timeout intervalin seconds after which if no data has been received from the client, sshd willsend a message through the encrypted channel to request a response from the client.The default is 0, indicating that these messages will not be sent to the client.-`ClientAliveCountMax` sets the number of client alive messages which may be sentwithout sshd receiving any messages back from the client. If this threshold isreached while client alive messages are being sent, sshd will disconnect the client,terminating the session. The default value is 3.    - The client alive messagesare sent through the encrypted channel     - Setting `ClientAliveCountMax` to0 disables connection terminationExample: The default value is 3. If `ClientAliveInterval`is set to 15, and `ClientAliveCountMax` is left at the default, unresponsive SSHclients will be disconnected after approximately 45 seconds## RationaleHaving no timeout value associated with a connection could allow an unauthorized user access to another user's ssh session (e.g. user walks away from their computer and doesn't lock the screen). Setting a timeout value reduces this risk.- The recommended `ClientAliveInterval` setting is no greater than 900 seconds (15 minutes)- The recommended `ClientAliveCountMax` setting is 0- At the 15 minute interval, if the ssh session is inactive, the session will be terminated.## ImpactIn some cases this setting may cause termination of long-running scripts over SSH or remote automation tools which rely on SSH. In developing the local site policy, the requirements of such scripts should be considered and appropriate ServerAliveInterval and `ClientAliveInterval` settings should be calculated to insure operational continuity.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::ssh_idle_timeout_interval_is_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `ssh_idle_timeout_interval_is_configured` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.2.20- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.2.20
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::ssh_idle_timeout_interval_is_configured () {
  linux_secured_setup { "ssh_idle_timeout_interval_is_configured on ${title}":
    ensure => 'present',
  }

  -> ini_setting { 'configured ClientAliveCountMax':
    ensure            => present,
    path              => '/etc/ssh/sshd_config',
    key_val_separator => ' ',
    setting           => 'ClientAliveCountMax',
    value             => '0',
  }

  -> ini_setting { 'configured ClientAliveInterval':
    ensure            => present,
    path              => '/etc/ssh/sshd_config',
    key_val_separator => ' ',
    setting           => 'ClientAliveInterval',
    value             => '900',
  }
}
