#
# linux_secured::controls::ssh_loglevel_is_appropriate
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the control`INFO` level is the basic level that only records login activity of SSH users. In many situations, such as Incident Response, it is important to determine when a particular user was active on a system. The logout record can eliminate those users who disconnected, which helps narrow the field.`VERBOSE` level specifies that login and logout activity as well as the key fingerprint for any SSH key used for login will be logged. This information is important for SSH key management, especially in legacy environments.## RationaleSSH provides several logging levels with varying amounts of verbosity. `DEBUG` is specifically not recommended other than strictly for debugging SSH communications since it provides so much data that it is difficult to identify important security information.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::ssh_loglevel_is_appropriate: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `ssh_loglevel_is_appropriate` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.2.5- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.2.5
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::ssh_loglevel_is_appropriate (
  Enum['INFO', 'VERBOSE'] $log_level = linux_secured::lookup_setting('log_level', 'INFO' )
) {
  linux_secured_setup { "ssh_loglevel_is_appropriate on ${title}":
    ensure => 'present',
  }

  -> ini_setting { 'configured LogLevel':
    ensure            => present,
    path              => '/etc/ssh/sshd_config',
    key_val_separator => ' ',
    setting           => 'LogLevel',
    value             => $log_level,
  }
}
