#
# linux_secured::controls::sticky_bit_is_set_on_all_world_writable_directories
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlSetting the sticky bit on world writable directories prevents users from deleting or renaming files in that directory that are not owned by them.## RationaleThis feature prevents the ability to delete or rename files in world writable directories (such as `/tmp` ) that are owned by another user.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::sticky_bit_is_set_on_all_world_writable_directories: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `sticky_bit_is_set_on_all_world_writable_directories` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 6.1.2- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 6.1.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::sticky_bit_is_set_on_all_world_writable_directories () {
  linux_secured_setup { "sticky_bit_is_set_on_all_world_writable_directories on ${title}":
    ensure => 'present',
  }

  # lint:ignore:strict_indent
  exec { 'sticky bit is set on all world-writable directories':
    path    => ['/bin'],
    command => @(SCRIPT),
    df --local -P | awk '{if (NR!=1) print $6}' | xargs -I '{}' find '{}' -xdev -type d \( -perm -0002 -a ! -perm -1000 \) 2>/dev/null
    | SCRIPT
    unless  => @(SCRIPT),
    df --local -P | awk '{if (NR!=1) print $6}' | xargs -I '{}' find '{}' -xdev -type d \( -perm -0002 -a ! -perm -1000 \) 2>/dev/null | xargs -I '{}' chmod a+t '{}'
    | SCRIPT
  }
  # lint:endignore:strict_indent
}
