#
# linux_secured::controls::successful_file_system_mounts_are_collected
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlMonitor the use of the `mount` system call. The `mount` (and `umount`)system call controls the mounting and unmounting of file systems. The parametersbelow configure the system to create an audit record when the `mount` system callis used by a non-privileged user## RationaleIt is highly unusual for a non-privileged user to `mount` file systems to the system. While tracking `mount` commands gives the system administrator evidence that external media may have been mounted (based on a review of the source of the `mount` and confirming it's an external media type), it does not conclusively indicate that data was exported to the media. System administrators who wish to determine if data were exported, would also have to track successful `open`, `creat` and `truncate` system calls requiring write access to a file under the `mount` point of the external media file system. This could give a fair indication that a write occurred. The only way to truly prove it, would be to track successful writes to the external media. Tracking write system calls could quickly fill up the audit log and is not recommended. Recommendations on configuration options to track data export to media is beyond the scope of this document.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::successful_file_system_mounts_are_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `successful_file_system_mounts_are_collected` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.10- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.10
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::successful_file_system_mounts_are_collected () {
  linux_secured_setup { "successful_file_system_mounts_are_collected on ${title}":
    ensure => 'present',
  }

  -> file { '/etc/audit/rules.d/50-mount.rules':
    ensure  => 'file',
    # lint:ignore:strict_indent
    content => @("CONTENT"),
    -a always,exit -F arch=b32 -S mount -F auid>=${facts['uid_min'] } -F auid!=unset -k mounts
    -a always,exit -F arch=b64 -S mount -F auid>=${facts['uid_min'] } -F auid!=unset -k mounts
    | CONTENT
    # lint:endignore:strict_indent
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    notify  => Exec['refresh audit deamon'],
  }

  include linux_secured::internal::refresh_audit_daemon
}
