#
# linux_secured::controls::sudo_authentication_timeout_is_configured_correctly
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the control`sudo` caches used credentials for a default of 5 minutes. This isfor ease of use when there are multiple administrative tasks to perform. The timeoutcan be modified to suit local security policies.## RationaleSetting a timeout value reduces the window of opportunity for unauthorized privileged access to another user.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::sudo_authentication_timeout_is_configured_correctly: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `sudo_authentication_timeout_is_configured_correctly` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.3.6- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.3.6
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::sudo_authentication_timeout_is_configured_correctly (
  Integer[0,15] $timeout = linux_secured::lookup_setting('timeout', 15),
) {
  linux_secured_setup { "sudo_authentication_timeout_is_configured_correctly on ${title}":
    ensure => 'present',
  }

  if $facts['contains_sudo_timestamp_timeout'] == [] {
    ini_setting { 'Configure sudo authentication timeout':
      ensure            => present,
      path              => '/etc/suoders',
      key_val_separator => '=',
      setting           => 'timestamp_timeout',
      value             => $timeout,
    }
  } else {
    $facts['contains_sudo_timestamp_timeout'].each |$file| {
      ini_setting { "Configure sudo authentication timeout in ${file}":
        ensure            => present,
        path              => $file,
        key_val_separator => '=',
        setting           => 'timestamp_timeout',
        value             => $timeout,
      }
    }
  }
}
