#
# linux_secured::controls::system_is_disabled_when_audit_logs_are_full
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `auditd` daemon can be configured to halt the system when the audit logs are full. The `admin_space_left_action` parameter tells the system what action to take when the system has detected that it is low on disk space. Valid values are ignore, syslog, suspend, single, and halt.- ignore, the audit daemon does nothing- Syslog, the audit daemon will issue a warning to syslog- Suspend, the audit daemon will stop writing records to the disk- halt, the audit daemon will shutdown the system## RationaleIn high security contexts, the risk of detecting unauthorized access or nonrepudiation exceeds the benefit of the system's availability.## Impact## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::system_is_disabled_when_audit_logs_are_full: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `system_is_disabled_when_audit_logs_are_full` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.2.3- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.2.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::system_is_disabled_when_audit_logs_are_full (
  Enum['halt', 'single'] $action = linux_secured::lookup_setting('action', 'halt'),
) {
  linux_secured_setup { "system_is_disabled_when_audit_logs_are_full on ${title}":
    ensure => 'present',
  }

  -> ini_setting { 'system send mail when audit logs are full':
    ensure  => present,
    path    => '/etc/audit/auditd.conf',
    setting => 'space_left_action',
    value   => 'email',
  }

  -> ini_setting { 'system send mail as root when audit logs are full':
    ensure  => present,
    path    => '/etc/audit/auditd.conf',
    setting => 'action_mail_acct',
    value   => 'root',
  }

  -> ini_setting { 'system is disabled when audit logs are full':
    ensure  => present,
    path    => '/etc/audit/auditd.conf',
    setting => 'admin_space_left_action',
    value   => $action,
  }
}
