#
# linux_secured::controls::system_wide_crypto_policy_is_not_legacy
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe system-wide crypto-policies followed by the crypto core components allow consistently deprecating and disabling algorithms system-wide.The individual policy levels (DEFAULT, LEGACY, FUTURE, and FIPS) are included in the crypto-policies(7) package.## RationaleIf the Legacy system-wide crypto policy is selected, it includes support for TLS 1.0, TLS 1.1, and SSH2 protocols or later. The algorithms DSA, 3DES, and RC4 are allowed, while RSA and Diffie-Hellman parameters are accepted if larger than 1023-bits.These legacy protocols and algorithms can make the system vulnerable to attacks, including those listed in RFC 7457## ImpactEnvironments that require compatibility with older insecure protocols may require the use of the less secure LEGACY policy level.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::system_wide_crypto_policy_is_not_legacy: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `system_wide_crypto_policy_is_not_legacy` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.10- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.10
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::system_wide_crypto_policy_is_not_legacy (
  Optional[Enum['DEFAULT', 'FUTURE']] $policy = linux_secured::lookup_setting('policy', 'DEFAULT'),
) {
  linux_secured_setup { "system_wide_crypto_policy_is_not_legacy on ${title}":
    ensure => 'present',
  }
  unless $policy == undef {
    unless defined( Package['crypto-policies-scripts']) {
      package { 'crypto-policies-scripts':
        ensure => 'installed',
      }
    }
    exec { "Update crypto policies on ${title}":
      command => "update-crypto-policies --set ${policy}; update-crypto-policies",
      path    => '/usr/bin',
      unless  => 'grep -E -i \'^\\s*LEGACY\s*(\\s+#.*)?$\' /etc/crypto-policies/config',
      require => [
        Linux_secured_setup["system_wide_crypto_policy_is_not_legacy on ${title}"],
        Package['crypto-policies-scripts'],
      ],
    }
  } else {
    easy_type::delegate_to_validator()
  }
}
