#
# linux_secured::controls::tcp_syn_cookies_is_enabled
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlWhen tcp_syncookies is set, the kernel will handle TCP SYN packetsnormally until the half-open connection queue is full, at which time, the SYNcookie functionality kicks in. SYN cookies work by not using the SYN queue atall. Instead, the kernel simply replies to the SYN with a SYN|ACK, but will includea specially crafted TCP sequence number that encodes the source and destinationIP address and port number and the time the packet was sent. A legitimate connectionwould send the ACK packet of the three way handshake with the specially craftedsequence number. This allows the system to verify that it has received a validresponse to a SYN cookie and allow the connection, even though there is no correspondingSYN in the queue.## RationaleAttackers use SYN flood attacks to perform a denial of service attacked on a system by sending many SYN packets without completing the three way handshake. This will quickly use up slots in the kernel's half-open connection queue and prevent legitimate connections from succeeding. SYN cookies allow the system to keep accepting valid connections, even if under a denial of service attack.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::tcp_syn_cookies_is_enabled: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `tcp_syn_cookies_is_enabled` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.3.8- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.3.8
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::tcp_syn_cookies_is_enabled () {
  linux_secured_setup { "tcp_syn_cookies_is_enabled on ${title}":
    ensure => 'present',
  }

  -> sysctl { 'net.ipv4.tcp_syncookies':
    ensure => present,
    value  => '1',
  }
}
