#
# linux_secured::controls::use_of_privileged_commands_are_collected
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlbit set on execution, to determine if unprivileged users are running these commands.## RationaleExecution of privileged commands by non-privileged users could be an indication of someone trying to gain unauthorized access to the system.## ImpactBoth the audit and remediation section of this recommendation will traverse all mounted file systems that is not mounted with either noexec or nosuid mount options. If there are large file systems without these mount options, such traversal will be significantly detrimental to the performance of the system.Before running either the audit or remediation section, inspect the output of the following command to determine exactly which file systems will be traversed:```findmnt -n -l -k -it $(awk '/nodev/ { print $2 }' /proc/filesystems | paste -sd,) | grep -Pv "noexec|nosuid"```## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::use_of_privileged_commands_are_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `use_of_privileged_commands_are_collected` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.6- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.6
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::use_of_privileged_commands_are_collected () {
  # lint:ignore:strict_indent
  $template = @(TEMPLATE)
  <% $facts['privileged_commands'].each |$privileged_command| { -%>
  -a always,exit -F path=<%= $privileged_command %> -F perm=x -F auid>=<%= $facts['uid_min'] %> -F auid!=unset -k privileged
  <% } -%>
  | TEMPLATE
  # lint:endignore:strict_indent

  linux_secured_setup { "use_of_privileged_commands_are_collected on ${title}":
    ensure => 'present',
  }

  -> file { '/etc/audit/rules.d/50-privileged.rules':
    ensure  => 'file',
    content => inline_epp($template),
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    notify  => Exec['refresh audit deamon'],
  }

  include linux_secured::internal::refresh_audit_daemon
}
