#
# linux_secured::controls::users_must_provide_password_for_escalation
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe operating system must be configured so that users must providea password for privilege escalation.## RationaleWithout re-authentication, users may access resources or perform tasks for which they do not have authorization.## ImpactThis will prevent automated processes from being able to elevate privileges. To include Ansible and AWS builds## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::users_must_provide_password_for_escalation: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `users_must_provide_password_for_escalation` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.3.4- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.3.4
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::users_must_provide_password_for_escalation () {
  linux_secured_setup { "users_must_provide_password_for_escalation on ${title}":
    ensure => 'present',
  }

  $facts['contains_sudo_nopasswd_rules'].each |$sudo_file| {
    file_line { "Remove NOPASSWD directive in ${sudo_file}":
      ensure            => 'absent',
      path              => $sudo_file,
      match             => '^[^#].*NOPASSWD',
      match_for_absence => true,
      require           => Linux_secured_setup["users_must_provide_password_for_escalation on ${title}"],
    }
  }
}
