#
# linux_secured::controls::users_netrc_files_are_not_group_or_world_accessible
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlWhile the system administrator can establish secure permissions for users' .netrc files, the users can easily override these.## RationaleThe `.netrc` file presents a significant security risk since it stores passwords in unencrypted form. Even if FTP is disabled, user accounts may have brought over `.netrc` files from other systems which could pose a risk to those systems.If a `.netrc` file is required, and follows local site policy, it should have permissions of `600` or more restrictive.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::users_netrc_files_are_not_group_or_world_accessible: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `users_netrc_files_are_not_group_or_world_accessible` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 6.2.13- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 6.2.13
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::users_netrc_files_are_not_group_or_world_accessible {
  linux_secured_setup { "users_netrc_files_are_not_group_or_world_accessible on ${title}":
    ensure => 'present',
  }

  $facts['to_permissive_netrc_files'].each |$file| {
    file { $file:
      mode    => '0600',
      require => Linux_secured_setup["users_netrc_files_are_not_group_or_world_accessible on ${title}"],
    }
  }
}
