#
# linux_secured::controls::xinetd_is_not_installed
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe eXtended InterNET Daemon ( xinetd ) is an open source super daemonthat replaced the original inetd daemon. The xinetd daemon listens for well knownservices and dispatches the appropriate daemon to properly respond to servicerequests.## RationaleIf there are no xinetd services required, it is recommended that the package be removed to reduce the attack surface are of the system.**Note**: If an xinetd service or services are required, ensure that any xinetd service not required is stopped and disabled## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::xinetd_is_not_installed: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `xinetd_is_not_installed` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 2.2.1- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 2.2.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::xinetd_is_not_installed () {
  linux_secured_setup { "xinetd_is_not_installed on ${title}":
    ensure => 'present',
  }

  package { 'xinetd':
    ensure => 'purged',
  }
}
