#
# linux_secured::controls::permissions_on_bootloader_config_are_configured
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe grub files contain information on boot settings and passwords for unlocking boot options.The grub2 configuration is usually grub.cfg. On newer grub2 systems the encrypted bootloader password is contained in user.cfg.If the system uses UEFI, /boot/efi is a vfat filesystem. The vfat filesystem itself doesn't have the concept of permissions but can be mounted under Linux with whatever permissions desired.## RationaleSetting the permissions to read and write for root only prevents non-root users from seeing the boot parameters or changing them. Non-root users who read the boot parameters may be able to identify weaknesses in security upon boot and be able to exploit them.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::permissions_on_bootloader_config_are_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `permissions_on_bootloader_config_are_configured` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.4.2- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.4.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::permissions_on_bootloader_config_are_configured () {
  linux_secured_setup { "permissions_on_bootloader_config_are_configured on ${title}":
    ensure => 'present',
  }

  -> file { ['/boot/grub2/grubenv','/boot/grub2/grub.cfg']:
    mode  => '0600',
    owner => 'root',
    group => 'root',
  }
}
