#
# linux_secured::controls::remote_login_warning_banner_is_configured_properly
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe contents of the `/etc/issue.net` file are displayed to users prior to login for remote connections from configured services.Unix-based systems have typically displayed information about the OS release and patch level upon logging in to the system. This information can be useful to developers who are developing software for a particular OS platform. If mingetty(8) supports the following options, they display operating system information: \m - machine architecture \r - operating system release \s - operating system name \v - operating system version## RationaleWarning messages inform users who are attempting to login to the system of their legal status regarding the system and must include the name of the organization that owns the system and any monitoring policies that are in place. Displaying OS and patch level information in login banners also has the side effect of providing detailed system information to attackers attempting to target specific exploits of a system. Authorized users can easily get this information by running the " uname -a " command once they have logged in.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::remote_login_warning_banner_is_configured_properly: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `remote_login_warning_banner_is_configured_properly` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.7.3- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.7.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::remote_login_warning_banner_is_configured_properly (
  Optional[String[1]] $message = linux_secured::lookup_setting('message', 'Authorized uses only. All activity may be monitored and reported.'),
) {
  linux_secured_setup { "remote_login_warning_banner_is_configured_properly on ${title}":
    ensure => 'present',
  }

  if $message == undef {
    easy_type::delegate_to_validator()
  } else {
    $random = easy_type::random_id(8)
    resource_merge { "File[/etc/issue.net]${random}":
      allow_redefine => true,
      allow_create   => true,
      properties     => {
        ensure  => 'file',
        content => $message,
        owner   => 'root',
        group   => 'root',
        mode    => '0644',
      },
    }
  }
}
