#
# linux_secured::controls::ssh_allowtcpforwarding_is_disabled
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlSSH port forwarding is a mechanism in SSH for tunneling applicationports from the client to the server, or servers to clients. It can be used foradding encryption to legacy applications, going through firewalls, and some systemadministrators and IT professionals use it for opening backdoors into the internalnetwork from their home machines## RationaleLeaving port forwarding enabled can expose the organization to security risks and back- doors.SSH connections are protected with strong encryption. This makes their contents invisible to most deployed network monitoring and traffic filtering solutions. This invisibility carries considerable risk potential if it is used for malicious purposes such as data exfiltration. Cybercriminals or malware could exploit SSH to hide their unauthorized communications, or to exfiltrate stolen data from the target network## ImpactSSH tunnels are widely used in many corporate environments that employ mainframe systems as their application backends. In those environments the applications themselves may have very limited native support for security. By utilizing tunneling, compliance with SOX, HIPAA, PCI-DSS, and other standards can be achieved without having to modify the applications.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::ssh_allowtcpforwarding_is_disabled: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `ssh_allowtcpforwarding_is_disabled` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.2.13- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.2.13
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::ssh_allowtcpforwarding_is_disabled () {
  linux_secured_setup { "ssh_allowtcpforwarding_is_disabled on ${title}":
    ensure => 'present',
  }

  -> ini_setting { 'configured AllowTcpForwarding':
    ensure            => present,
    path              => '/etc/ssh/sshd_config',
    key_val_separator => ' ',
    setting           => 'AllowTcpForwarding',
    value             => 'no',
  }
}
